% --------------------------STATE EQUATIONS-------------------------- 

   function dxdt=SMabcrelf2(t,x,Ra,Rkd,Rkq,Ld,Lq,Lal,Lkd,Lkq,Lakd,Lakq,Vm,wo,H,Bm,TLi,TLf,t1)

  % ---------------------- INPUTS -----------------------------------------     
      if t<t1, TL=TLi;  else TL=TLf;    end    
     
     gam=2*pi/3;
     vas=Vm*cos(wo*t);    vbs=Vm*cos(wo*t-gam);  vcs=Vm*cos(wo*t+gam);
   
   % ------------------------------------------------------------------------
         % State variable vector:
         %                x=[ias ibs ics ikd ikq wm theta]
   Lad=Ld-Lal;   Laq=Lq-Lal;
   L2=(Lad-Laq)/2;
   Lm=(Lad+Laq)/2;
   Lao=Lm+Lal;   Labo=-0.5*Lm; 
                   
   wm=x(6) ;          % speed
   theta=x(7);        % angle
   
    V=[vas vbs vcs 0 0]';                    % Voltage vector
    I=x(1:5) ;                               % Current vector
    
    R=diag([Ra Ra Ra Rkd Rkq]);              % Resistance matrix   
    
     % Inductance matrices :
      Laa=Lao+L2*cos(2*theta);           Lab=Labo+L2*cos(2*theta-gam);
      Lbb=Lao+L2*cos(2*(theta-gam));     Lbc=Labo+L2*cos(2*theta);
      Lcc=Lao+L2*cos(2*(theta+gam));     Lac=Labo+L2*cos(2*theta+gam);
           
    Lss=[Laa   Lab Lac   
         Lab   Lbb Lbc 
         Lac   Lbc Lcc]; 
    
    Lrr=[Lkd  0
          0  Lkq]; 
      
    Lsr=[Lakd* cos(theta)     -Lakq*sin(theta)
         Lakd*cos(theta-gam)  -Lakq*sin(theta-gam)
         Lakd*cos(theta+gam)  -Lakq*sin(theta+gam)];
    
     dLss=-2*L2*[sin(2*theta)       sin(2*theta-gam)  sin(2*theta+gam)  
                  sin(2*theta-gam) sin(2*(theta-gam))    sin(2*theta)
                  sin(2*theta+gam)   sin(2*theta)    sin(2*(theta+gam))];  
         
    dLsr=[-Lakd*sin(theta)      -Lakq*cos(theta)
          -Lakd*sin(theta-gam)  -Lakq*cos(theta-gam)
          -Lakq*sin(theta+gam)  -Lakq*cos(theta+gam)];
      
     L=[Lss  Lsr                     
        Lsr' Lrr];                   % Inductance matrix
       
    dLdtheta=[dLss     dLsr         
              dLsr'    zeros(2)];    % dL/dtheta
                   
        
    Te=0.5*I'*dLdtheta*I ;           % Electromagnetic torque
 
  %%% Matrix formulation of synchronous machine equations in abc stationary reference frame| 
  %%% Constitutive flux-current relations:
  %%%    F = L*I   or  I = L\F  
  %%% Electrical system equations:
  %%%    V= R*I + dF/wodt = R*I + d(L*I)/wodt = (R + wm*dL/dtheta)*I + L*dI/wodt  
  %%% Mechanical system equation:
  %%%    Te = 2*H*dwm/dt + TL + Bm*wm
  %%%                                     see refs. 14 -- 23
    
   didt=L\(V-(R+wm*dLdtheta)*I)*wo;       % Electrical system equations
   dwmdt=(Te-TL)/(2*H)-Bm*wm/(2*H);       % Mechanical system equation
   
   dxdt=[didt;dwmdt;wm*wo];               % State equations arrived at by concatenation
   
 %%% ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~  