%                <<<   INDUCTION MOTOR TRANSIENTS  >>>
%          Motor is initialized at a specified operating condition
clear,clc
disp(date)
disp('        <<<    Induction motor transients  >>>         ')
disp('               [ Sinusoidal excitation  ]              ')
disp('                    ( SI units  )               ')
% ---------------------------  DATA  ------------------------------------------
%           Machine parameters :  
Vll=220    ; %Line-to-line rms voltage rating [V]
HP=5.0     ; %Horsepower rating [hp]
Rs=0.531   ; %Stator resistance (Ohm)
Rr=0.408   ; %Rotor resistance  (Ohm)
Lsl=2.5e-3 ; %Stator leakage inductance (Henry)
Lrl=2.5e-3 ; %Rotor leakage inductance  (Henry)
Lm=85e-3   ; %Magnetizing inductance  (Henry) 
vs=1.0     ; %Stator voltage (pu)
ws=1.0     ; %Stator frequency (pu)
freq0=60;  %Base frequency (Hz)
wo=2*pi*freq0 ; %Base frequency (rad/s)
Vo=Vll*sqrt(2/3); %Base voltage [V]
p=4 ;   %number of poles
To=p/2*HP*746/wo; %Base torque [N.m]
J=0.03    ; %Moment of inertia (kg.m^2)
Bm=1e-9 ; %Torque speed coefficient

n0=0.95 ; %per-unit operating speed
wk=ws   ; %Synchronous frame

disp('    Rs        Lsl       Rr        Lrl       Lm')
param1=[Rs Lsl  Rr Lrl Lm];
disp(param1)
disp('    slip    voltage    frequency  poles     inertia   Bm ')
param2=[1-n0 Vo freq0 p J Bm];
disp(param2)

wmec0=n0*wo*2/p;  %Speed [rad/s]
%      Phasor analysis of steady-state equivalent circuit
    Zr=Rr/(ws-n0)+1i*wo*Lrl; Zm=1i*wo*Lm*Zr/(1i*wo*Lm+Zr);  Zin=Rs/ws+1i*wo*Lsl+Zm;
    Is=Vo/(ws*Zin);  Ir=-Is*1i*wo*Lm/(1i*wo*Lm+Zr);
    Req=real(Zm);    Te0=0.75/wo*p*(Is*conj(Is)*Req); Tl0=Te0/To;
    phis=(Lsl+Lm)*Is+Lm*Ir;  phir=Lm*Is+(Lrl+Lm)*Ir; 
    phids=real(phis);  phiqs=imag(phis);
    phidr=real(phir);  phiqr=imag(phir);
    Istat0=abs(Is);
    op=[wmec0  Te0  Istat0];    disp('   Speed     Torque    Current')  
    disp(op) 
    fs0=[phids phiqs];
    fr0=[phidr phiqr];    %initial conditions
%ic=zeros(5,1)
