%  V/f control of IM [SI]  <imvf1.m>
clc,clear
% ~~~~~~~~~~~~~~~~~~~ DATA (SI)~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
Vll=220    ; %Line-to-line rms voltage rating [V]
HP=10.0    ; %Horsepower rating [hp]
Rs=0.294   ; %Stator resistance (Ohm)
Rr=0.144   ; %Rotor resistance  (Ohm)
fo=60      ; %Base frequency (Hz)
wo=2*pi*fo ; %Base frequency (rad/s)
Lsl=0.00134; %Stator leakage inductance (H)
Lrl=5.4e-4;%Rotor leakage inductance  (H)
Lm=0.0353  ; %Magnetizing inductance  (H) 
p=6;         %number of poles
d=0.15;      %boost factor introduced in the applied voltage to compensate ... 
             %for effects of Rs at low frequencies (speeds)
n1=0; dn=0.1; n2=1.3;  % frequency (speed) steps [pu]         
% ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
if round(p/2)~=p/2;
 warndlg('  p must be even','error');
 break
end
if n1<0, n1=0; end
Vn=Vll/sqrt(3);       %Base voltage L-n rms 
Zmag=Rr+j*wo*(Lm+Lsl);
Imag=abs(Vn/Zmag);    %magnetizing current at base voltage
f=[n1:dn:n2];         %input frequency steps [pu]
v=abs((1-d)*f+d);     %adjusted input voltage [pu]
co=['bbgmcmybgcrkkkcybgrmck']; %color scheme

figure('Units','Normalized','Position',[.02 .1 .6 .79],...
     'Name','CONSTANT Volts/Hertz CHARACTERISTICS OF IM','NumberTitle','on')
 
  L=length(f);
 for k=2:L
   if abs(f(k))>1, v(k)=1; end
   if f(k)==0, f(k)=.0001; end
    n=n1:.001:f(k)+0.01;
    Zr=Rr*f(k)./(f(k)-n+eps)+j*Lrl*wo*f(k);
    Zf=j*wo*Lm*f(k).*Zr./(j*Lm*wo*f(k)+Zr+eps);
    Zin=Rs+j*wo*Lsl*f(k)+Zf;
    Rf=real(Zf); 
    Is=v(k)*Vn./Zin;  %rms
    Te=1.5*p*(Is.*conj(Is)./(f(k)+eps)/wo.*Rf);
    Is=abs(Is);
    Tm(k)=max(Te);
    q=find(max(Te)==Te);
 speed=n*120*fo/p;
    nm(k)=speed(q);
 spd2=n2*120*fo/p; 
 spd1=n1*120*fo/p;
     Tm(1)=NaN;
         
 subplot(211);
    plot(speed,Te,co(k)),title('V/f control of induction motor','color','r','fontsize',14),
    xlabel('SPEED [rpm] '),ylabel('TORQUE [N-m]'),hold on,grid
    plot(nm,Tm,'--b')
    set(gca,'Xlim',[spd1 spd2],'Ylim',[0 inf+10])
    if p<6, incr=200; else incr=100; end
    set(gca,'Xtick',[spd1:incr:spd2])
    set(findobj(gca,'type','line','color','r'),'linewidth',2)
    text(140*(k-3),-30,['f = ',num2str(f(k))],'color',co(k),'FontSize',8,'FontWeight','bold')
    text(140*(k-3),-41,['v = ',num2str(v(k))],'color',co(k),'FontSize',8,'FontWeight','bold')
    legend('Tmax')
   
 subplot(212)
    plot(speed,Is,co(k)),grid,title('Steady-state characteristics','color','r','fontsize',13)
    xlabel('SPEED [rpm] '),ylabel('CURRENT [A]'),hold on
    set(gca,'Xlim',[spd1 spd2]) 
    if p<6, incr=200; else incr=100; end
    set(gca,'Xtick',[spd1:incr:spd2])
    set(findobj(gca,'type','line','color','r'),'linewidth',2)   
    pause(1)
end

    line([spd1 spd2],[Imag Imag],'color','r','linestyle',':')
    text(20,Imag+11,'~Imag','color','r')

uicontrol('Units','normalized', ...
   'Style','PushButton',...
	'BackgroundColor',[.5 .5 .5], ...
	'Callback','edit imvf1', ...
	'FontSize',10, ...
	'FontWeight','bold', ...
	'ForegroundColor',[1 1 1], ... 
	'Position',[0.08 0.01 0.07 .04], ...
	'String','Edit', ...
    'TooltipString','edit'); 
uicontrol('Units','normalized', ...
   'Style','PushButton',...
	'BackgroundColor',[.5 .5 .5], ...
	'Callback','close all,clc,clear', ...
	'FontSize',10, ...
	'FontWeight','bold', ...
	'ForegroundColor',[1 1 1], ...
	'Position',[0.9 0.01 0.07 .04], ...
	'String','Close', ...
    'TooltipString','close'); 
uicontrol('Units','normalized', ...
   'Style','PushButton',...
	'BackgroundColor',[.5 .5 .5], ...
	'Callback','imvf1', ...
	'FontSize',10, ...
	'FontWeight','bold', ...
	'ForegroundColor',[1 1 1], ...
	'Position',[0.2 0.01 0.07 .04], ...
	'String','Run', ...
    'TooltipString','run'); 
uicontrol('Units','normalized', ...
   'Style','PushButton',...
	'BackgroundColor',[.5 .5 .5], ...
	'Callback','labelvf', ...
	'FontSize',10, ...
	'FontWeight','bold', ...
	'ForegroundColor',[1 1 1], ...
	'Position',[0.78 0.01 0.07 .04], ...
	'String','Info', ...
    'TooltipString','info'); 

figure('Units','Normalized','Position',[.625 .29 .36 .56],...
     'Name','Applied voltage','NumberTitle','on')
    plot(f*fo,v*Vn,'b',f*fo,f*Vn,'--g',fo,0,'or',fo,Vn,'or'),xlabel('Frequency [Hz]'),ylabel('Applied Voltage [V]'),...
    title('Applied voltage as function of frequency','color','r','fontsize',12),grid
   legend('Ajusted voltage','V/f constant',2)
    text(2,.9*d*Vn,'boost','color','m')
     text(fo,1.03*Vn,'Rated voltage','color','m')
     text(fo-10,0.03*Vn,'Rated frequency','color','r')
     
%%%%%%%