%     SPACE VECTOR DECOMPOSITION in SINUSOIDAL STEADY STATE
clc,clear,close all
disp(date)
info= ...
        ['              SPACE VECTOR DECOMPOSITION              ' 
         '           [Balanced sinusoidal steady state]         '  
         ' This demo animates the motion of a space vector under'   
         ' balanced sinusoidal conditions. It is seen as a      '
         ' constant amplitude vector rotating at the excitation '  
         ' frequency. Its components depend on the choice of    '
         ' reference frame. In the stationary ab frame, the     '
         ' components are time varying representing two-phase   '
         ' sinusoidal signals at stator frequency. In the       '
         ' rotating synchronous dq frame, the dq components of  '
         ' the space vector now appear as a pair of constants.  '
         ' The specific values depend on the orientation of the '
         ' space vector with respect to the dq axes.            '
         '                                                      '];  
disp(info)  
warning off
avitut=avifile('spavecab.avi','compression','cinepak');
%
      figure('units','normalized','Position',[.1 .1 .5 .36],'Name','Space vector components ',...
        'NumberTitle','off');
      set(gcf,'color','w')   
    e=0;e1=10*pi/90;
    E=pi/3; %orientation of PSI relative to dq axes
    M=1.5;     %magnitude of PSI
    fdx=M*cos(E);fdy=M*sin(E);
    zx=.8;zy=0.08;
    
    for k=1:360
       subplot(1,2,1)
       fa=M*cos(E+e1); fb=M*sin(E+e1);
     
     plot([-2.2 2.2],[0 0],'b'),hold on
     plot([0 0],[-2.2 2.2],'b')
     text(2.1,-0.1,'\alpha','color','b')
     text(-.18,2.15,'\beta','color','b')
     plot(0,0,'kx','MarkerSize',10,'linewidth',2)
     text(-2,-2.6,'Stationary \alpha \beta frame','color','b','Fontweight','b','fontsize',12)
     text(0.5,3,'Space vector decomposition','color',[0.5 0.5 0.5],'Fontweight','b','fontsize',16)
     text(1.5,2.52,'Sinusoidal steady state','color',[0.5 0.5 0.5],'Fontweight','b','fontsize',12)
    
    h1=plot([0 fa],[0 0],':k');
    h2=plot([fa fa],[0 fb],':k');
    h31=plot([0 M],[0 0],'g');
    h32=patch([zx*M M zx*M zx*M],[zy*M 0 -zy*M zy*M],'g','edgecolor','g');
    rotate(h31,[0 0 1],e+80,[0 0 0])
    rotate(h32,[0 0 1],e+80,[0 0 0])
    h4=text(fdx+.33*sign(fdx),fdy+0.33*sign(fdy),'\chi','color','g','fontsize',20,'fontweight','bold');
    h5=text(fa,fb,'\chi_\beta','color','k','fontsize',12,'fontweight','bold');
    h6=text(fa,-.1,'\chi_\alpha','color','k','fontsize',12,'fontweight','bold');
    rotate(h4,[0 0 1],e+20,[0 0 0])
          
    set(findobj(gca,'Type','line'),'LineWidth',2)  
      set(gca,'Xlim',[-2.5 2.5],'Ylim',[-2.5 2.5],'visible','off')
      axis ('equal')
      hold off
      
    subplot(1,2,2) 
     plot(0,0,'kx','MarkerSize',10,'linewidth',2),hold on
     plot([-2.2 2.2],[0 0],'b')
     plot([0 0],[-2.2 2.2],'b') 
     text(2.1,-0.1,'\alpha','color','b')
     text(-.19,2.15,'\beta','color','b')
     text(-2,-2.6,'Synchronous dq frame','color','r','Fontweight','b','fontsize',12)
    hd=plot([-2.2 2.2],[0 0],'color','r');  
    rotate(hd,[0 0 1],e+20,[0 0 0])
    htextd=text(2.1,-0.16,'d','color','r');
    rotate(htextd,[0 0 1],e+20,[0 0 0])
    htextq=text(-0.16,2.1,'q','color','r');
    rotate(htextq,[0 0 1],e+20,[0 0 0])
    hq=plot([0 0],[-2.2 2.2],'color','r') ;
    rotate(hq,[0 0 1],e+20,[0 0 0])
    h1=plot([0 fdx],[0 0],':k');
    rotate(h1,[0 0 1],e+20,[0 0 0])
    h2=plot([fdx fdx],[0 fdy],':k');
    rotate(h2,[0 0 1],e+20,[0 0 0])
    h31=plot([0 M],[0 0],'g');
   h32=patch([zx*M M zx*M zx*M],[zy*M 0 -zy*M zy*M],'g','edgecolor','g');
    rotate(h31,[0 0 1],e+80,[0 0 0])
    rotate(h32,[0 0 1],e+80,[0 0 0])
    h4=text(fdx+.33*sign(fdx),fdy+0.33*sign(fdy),'\chi','color','g','fontsize',20,'fontweight','bold');
    h5=text(fdx-.08,-.08,'\chi_d','color','k','fontsize',12,'fontweight','bold');
    h6=text(fdx,fdy-.09,'\chi_q','color','k','fontsize',12,'fontweight','bold');
    rotate(h4,[0 0 1],e+20,[0 0 0])
    rotate(h5,[0 0 1],e+20,[0 0 0])
    rotate(h6,[0 0 1],e+20,[0 0 0])
    
    set(findobj(gca,'Type','line'),'LineWidth',2)  
      set(gca,'Xlim',[-2.5 2.5],'Ylim',[-2.5 2.5],'visible','off')
      axis ('equal')
      hold off
      %          
      f=getframe(gcf);
      avitut=addframe(avitut,f);
      e=e+1;
      E=E+pi/180;
  end
   avitut=close(avitut);
     
  %
