% Synchronous generator compounding curve and phasor diagram
clear,close all
%DATA
V=1.0;
X=1;
pf=0.8; 
phi2=0;
phi1=acos(pf);phi3=-acos(pf);
%
q=0;
Ed1=[]; Eq1=[]; Id1=[]; Iq1=[];Im1=[];Em1=[];
Ed2=[]; Eq2=[]; Id2=[]; Iq2=[];Im2=[];Em2=[];
Ed3=[]; Eq3=[]; Id3=[]; Iq3=[];Im3=[];Em3=[];
avimov=avifile('syncgenb.avi','compression','none');
     
for P=0:.015:1.5
  q=q+1;  
  Im11=P;
  Ia1=Im11*exp(1i*phi1); Id11=real(Ia1); Iq11=imag(Ia1);
  Ea1=V+1i*X*Ia1;   Ed11=real(Ea1);  Eq11=imag(Ea1);  Em11=abs(Ea1);
  Ed1=[Ed1 Ed11]; Eq1=[Eq1 Eq11]; Id1=[Id1 Id11]; Iq1=[Iq1 Iq11]; Im1=[Im1 Im11];Em1=[Em1 Em11];
  
  Im22=P;
  Ia2=Im22*exp(1i*phi2); Id21=real(Ia2); Iq21=imag(Ia2);
  Ea2=V+1i*X*Ia2;   Ed21=real(Ea2);  Eq21=imag(Ea2);  Em21=abs(Ea2);
  Ed2=[Ed2 Ed21]; Eq2=[Eq2 Eq21]; Id2=[Id2 Id21]; Iq2=[Iq2 Iq21]; Im2=[Im2 Im22];Em2=[Em2 Em21];
  
  Im33=P;
  Ia3=Im33*exp(1i*phi3); Id31=real(Ia3); Iq31=imag(Ia3);
  Ea3=V+1i*X*Ia3;   Ed31=real(Ea3);  Eq31=imag(Ea3);  Em31=abs(Ea3);
  Ed3=[Ed3 Ed31]; Eq3=[Eq3 Eq31]; Id3=[Id3 Id31]; Iq3=[Iq3 Iq31]; Im3=[Im3 Im33];Em3=[Em3 Em31];
end

for k=1:q
    figure('Units','normalized','Position',[0.05 0.5 .9 .45],'Name','ALTERNATOR: Phasor diagrams','NumberTitle','off','menubar','none') 
    
 subplot(1,3,1)
  plot(0,0,'-k',0,0,'-b',0,0,'-g',0,0,'-r'),hold on
   legend('V','E','jXI','I',2)
vecarrow([0 0],[V 0],'k')
vecarrow([0 0],[Ed1(k) Eq1(k)],'b')
vecarrow([V 0],[Ed1(k) Eq1(k)],'g')
vecarrow([0 0],[Id1(k) Iq1(k)],'r')
set(gca,'Xlim',[-0.2 2],'Ylim',[-1.25 1.5])
axis('square'); axis('equal')
h=findobj(gca,'Type','line');
set(h,'LineWidth',2)
plot(Ed1,Eq1,'k--',Id1,Iq1,'k--')


for w=1:q
  plot(Ed1(w),Eq1(w),'k')
  plot(Id1(w),Iq1(w),'k')
end

plot(0,0,'kx','MarkerSize',10,'linewidth',2)
xlabel('V=1  pf=0.8(lead)  X=1','color',[.2 .2 .1],'fontsize',12,'Fontweight','b')

  
  subplot(1,3,2) 
plot(0,0,'-k',0,0,'-b',0,0,'-g',0,0,'-r'),hold on
   legend('V','E','jXI','I',2)  
vecarrow([0 0],[V 0],'k'),hold on
vecarrow([0 0],[Ed2(k) Eq2(k)],'b')
vecarrow([V 0],[Ed2(k) Eq2(k)],'g')
vecarrow([0 0],[Id2(k) Iq2(k)],'r')
set(gca,'Xlim',[-0.2 2],'Ylim',[-1.25 1.5])
axis('equal');
h=findobj(gca,'Type','line');
set(h,'LineWidth',2)
plot(Ed2,Eq2,'k--',Id2,Iq2,'k--')


for w=1:q
  plot(Ed2(w),Eq2(w),'k')
  plot(Id2(w),Iq2(w),'k')
end

plot(0,0,'kx','MarkerSize',10,'linewidth',2)
xlabel('V=1  pf=unity  X=1','color',[.2 .2 .1],'fontsize',12,'Fontweight','b')


   subplot(1,3,3) 
   plot(0,0,'-k',0,0,'-b',0,0,'-g',0,0,'-r'),hold on
   legend('V','E','jXI','I',2)
 vecarrow([0 0],[V 0],'k'),
 xlabel('Real axis','color',[.2 .6 .2],'Fontweight','b','fontsize',12),
 ylabel('Imaginary axis','color',[.2 .6 .2],'Fontweight','b','fontsize',12) ,hold on
vecarrow([0 0],[Ed3(k) Eq3(k)],'b')
vecarrow([V 0],[Ed3(k) Eq3(k)],'g')
vecarrow([0 0],[Id3(k) Iq3(k)],'r')
set(gca,'Xlim',[-0.2 2],'Ylim',[-1.25 1.5])
axis('equal');
h=findobj(gca,'Type','line');
set(h,'LineWidth',2)
plot(Ed3,Eq3,'k--',Id3,Iq3,'k--')


for w=1:q
  plot(Ed3(w),Eq3(w),'k')
  plot(Id3(w),Iq3(w),'k')
end

plot(0,0,'kx','MarkerSize',10,'linewidth',2)
xlabel('V=1  pf=0.8(lag)  X=1','color',[.2 .2 .1],'fontsize',12,'Fontweight','b')

 f=getframe(gcf);
  avimov=addframe(avimov,f); 
    
 figure('Units','normalized','Position',[0.05 0.06 .9 .4],'Name','ALTERNATOR: Compounding curves','NumberTitle','off','menubar','none') 
 plot(Im1,Em1,'-g',Im2,Em2,'-r',Im3,Em3,'-b'),
 ylabel('Field excitation E','color','b','Fontweight','b','fontsize',12),
 xlabel('Power P','color','r','Fontweight','b','fontsize',12) ,grid,hold on
 legend('0.8 pf lead','unity pf','0.8 pf lag',2)
 
 plot(Im1(k),Em1(k),'go','MarkerSize',5,'MarkerEdgeColor','g','MarkerFacecolor','g')
 plot(Im2(k),Em2(k),'ro','MarkerSize',5,'MarkerEdgeColor','r','MarkerFacecolor','r')
 plot(Im3(k),Em3(k),'bo','MarkerSize',5,'MarkerEdgeColor','b','MarkerFacecolor','b')
 
 axis([0 1.5 0 2.5]);
 h=findobj(gca,'Type','line');
 set(h,'LineWidth',2)
 
% f=getframe(gcf);
 %  avimov=addframe(avimov,f); 
 
 end  
  avimov=close(avimov);
