% Synchronous generator compounding curve and phasor diagram
clear,close all
%DATA
V=1.0;
X=1;
pf=0.8; 
phi2=0;
phi1=acos(pf);phi3=-acos(pf);
%
q=0;
Ed1=[]; Eq1=[]; Id1=[]; Iq1=[];Im1=[];Em1=[];
Ed2=[]; Eq2=[]; Id2=[]; Iq2=[];Im2=[];Em2=[];
Ed3=[]; Eq3=[]; Id3=[]; Iq3=[];Im3=[];Em3=[];
avimov=avifile('syncgen444.avi','compression','cinepak');
     
for P=0:.035:1.5
  q=q+1;  
  Im11=P;
  Ia1=Im11*exp(j*phi1); Id11=real(Ia1); Iq11=imag(Ia1);
  Ea1=V+j*X*Ia1;   Ed11=real(Ea1);  Eq11=imag(Ea1);  Em11=abs(Ea1);
  Ed1=[Ed1 Ed11]; Eq1=[Eq1 Eq11]; Id1=[Id1 Id11]; Iq1=[Iq1 Iq11]; Im1=[Im1 Im11];Em1=[Em1 Em11];
  
  Im22=P;
  Ia2=Im22*exp(j*phi2); Id21=real(Ia2); Iq21=imag(Ia2);
  Ea2=V+j*X*Ia2;   Ed21=real(Ea2);  Eq21=imag(Ea2);  Em21=abs(Ea2);
  Ed2=[Ed2 Ed21]; Eq2=[Eq2 Eq21]; Id2=[Id2 Id21]; Iq2=[Iq2 Iq21]; Im2=[Im2 Im22];Em2=[Em2 Em21];
  
  Im33=P;
  Ia3=Im33*exp(j*phi3); Id31=real(Ia3); Iq31=imag(Ia3);
  Ea3=V+j*X*Ia3;   Ed31=real(Ea3);  Eq31=imag(Ea3);  Em31=abs(Ea3);
  Ed3=[Ed3 Ed31]; Eq3=[Eq3 Eq31]; Id3=[Id3 Id31]; Iq3=[Iq3 Iq31]; Im3=[Im3 Im33];Em3=[Em3 Em31];
end

for k=1:q
    figure('Units','normalized','Position',[0.05 0.1 .9 .85],'Name','ALTERNATOR','NumberTitle','on') 
    
 subplot(3,2,1) 
 vecarrow([0 0],[V 0],'k'),
 xlabel('Real axis','color',[.2 .6 .2],'Fontweight','b','fontsize',12),
 ylabel('Imaginary axis','color',[.2 .6 .2],'Fontweight','b','fontsize',12) ,hold on
vecarrow([0 0],[Ed1(k) Eq1(k)],'b')
vecarrow([V 0],[Ed1(k) Eq1(k)],'g')
vecarrow([0 0],[Id1(k) Iq1(k)],'r')
set(gca,'Xlim',[-0.2 2],'Ylim',[-1.25 1.5])
axis('equal');
h=findobj(gca,'Type','line');
set(h,'LineWidth',2)
plot(Ed1,Eq1,'k--',Id1,Iq1,'k--')


for w=1:q
  plot(Ed1(w),Eq1(w),'k')
  plot(Id1(w),Iq1(w),'k')
end

plot(0,0,'kx','MarkerSize',10,'linewidth',2)
title('Phasor diagrams','fontsize',12,'Fontweight','b','color','k'),
hr=h(length(h):-1:1);
 legend(hr,'V','E','jXI','I',2)
% plot(0,0,'kx','MarkerSize',10,'linewidth',2)
 text(-0.20,-1.0,'V=1  pf=0.8(lead)  X=1','color',[.2 .2 .1],'fontsize',12,'Fontweight','b')
  %%%%
  
 subplot(3,2,2)
 plot(Im1,Em1,'-r',Im1(k),Em1(k),'*b'),title('Alternator compounding curves','fontsize',14),
 ylabel('Field excitation','color','b','Fontweight','b','fontsize',12),
 xlabel('Power P','color','r','Fontweight','b','fontsize',12) ,grid,
 axis([0 1.5 0 2.5]);
 h=findobj(gca,'Type','line');
 set(h,'LineWidth',2)
 
 subplot(3,2,3) 
 vecarrow([0 0],[V 0],'k'),
 xlabel('Real axis','color',[.2 .6 .2],'Fontweight','b','fontsize',12),
 ylabel('Imaginary axis','color',[.2 .6 .2],'Fontweight','b','fontsize',12) ,hold on
vecarrow([0 0],[Ed2(k) Eq2(k)],'b')
vecarrow([V 0],[Ed2(k) Eq2(k)],'g')
vecarrow([0 0],[Id2(k) Iq2(k)],'r')
set(gca,'Xlim',[-0.2 2],'Ylim',[-1.25 1.5])
axis('equal');
h=findobj(gca,'Type','line');
set(h,'LineWidth',2)
plot(Ed2,Eq2,'k--',Id2,Iq2,'k--')


for w=1:q
  plot(Ed2(w),Eq2(w),'k')
  plot(Id2(w),Iq2(w),'k')
end

plot(0,0,'kx','MarkerSize',10,'linewidth',2)
%title('Phasor diagrams','fontsize',12,'Fontweight','b','color','k'),
hr=h(length(h):-1:1);
 legend(hr,'V','E','jXI','I',2)
% plot(0,0,'kx','MarkerSize',10,'linewidth',2)
 text(-0.20,-1.0,'V=1  pf=unity  X=1','color',[.2 .2 .1],'fontsize',12,'Fontweight','b')
 
 subplot(3,2,4)
 plot(Im2,Em2,'-r',Im2(k),Em2(k),'*b'),%title('Alternator compounding curve','fontsize',14),
 ylabel('Field excitation','color','b','Fontweight','b','fontsize',12),
 xlabel('Power P','color','r','Fontweight','b','fontsize',12) ,grid,
 axis([0 1.5 0 2.5]);
 h=findobj(gca,'Type','line');
 set(h,'LineWidth',2)
 
  subplot(3,2,5) 
 vecarrow([0 0],[V 0],'k'),
 xlabel('Real axis','color',[.2 .6 .2],'Fontweight','b','fontsize',12),
 ylabel('Imaginary axis','color',[.2 .6 .2],'Fontweight','b','fontsize',12) ,hold on
vecarrow([0 0],[Ed3(k) Eq3(k)],'b')
vecarrow([V 0],[Ed3(k) Eq3(k)],'g')
vecarrow([0 0],[Id3(k) Iq3(k)],'r')
set(gca,'Xlim',[-0.2 2],'Ylim',[-1.25 1.5])
axis('equal');
h=findobj(gca,'Type','line');
set(h,'LineWidth',2)
plot(Ed3,Eq3,'k--',Id3,Iq3,'k--')


for w=1:q
  plot(Ed3(w),Eq3(w),'k')
  plot(Id3(w),Iq3(w),'k')
end

plot(0,0,'kx','MarkerSize',10,'linewidth',2)
%title('Phasor diagrams','fontsize',12,'Fontweight','b','color','k'),
hr=h(length(h):-1:1);
 legend(hr,'V','E','jXI','I',2)
% plot(0,0,'kx','MarkerSize',10,'linewidth',2)
 text(-0.20,-1.0,'V=1  pf=0.8(lag)  X=1','color',[.2 .2 .1],'fontsize',12,'Fontweight','b')
 
 subplot(3,2,6)
 plot(Im3,Em3,'-r',Im3(k),Em3(k),'*b'),%title('Alternator compounding curve','fontsize',14),
 ylabel('Field excitation','color','b','Fontweight','b','fontsize',12),
 xlabel('Power P','color','r','Fontweight','b','fontsize',12) ,grid,
 axis([0 1.5 0 2.5]);
 h=findobj(gca,'Type','line');
 set(h,'LineWidth',2)
 
 
 
  %%%%
 %%%%%
   f=getframe(gcf);
    avimov=addframe(avimov,f);
    % M(k)=getframe;
 end  
  avimov=close(avimov);
